@@ -1,5 +1,5 @@
 package Pod::Weaver::Section::Name;
-our $VERSION = '3.092970';
+our $VERSION = '3.092971';
 
 
 use Moose;
@@ -16,27 +16,29 @@ use Pod::Elemental::Element::Nested;
 sub weave_section {
   my ($self, $document, $input) = @_;
 
-# my $pkg_node = $self->weaver->ppi_doc->find_first('PPI::Statement::Package');
-#
-# Carp::croak
-#   sprintf "couldn't find package declaration in %s", $arg->{filename}
-#   unless $pkg_node;
-#
-# my $package = $pkg_node->namespace;
-#
-# $self->log([ "couldn't find abstract in %s", $arg->{filename} ])
-#    unless my ($abstract) = $self->weaver->ppi_doc->serialize =~ /^\s*#+\s*ABSTRACT:\s*(.+)$/m;
-#
-# my $name = $package;
-# $name .= " - $abstract" if $abstract;
+  return unless my $ppi_document = $input->{ppi_document};
+  my $pkg_node = $ppi_document->find_first('PPI::Statement::Package');
+
+  my $filename = 'file'; # $arg->{filename}
+
+  Carp::croak sprintf "couldn't find package declaration in %s", $filename
+    unless $pkg_node;
+
+  my $package = $pkg_node->namespace;
+
+  my ($abstract)
+    = $ppi_document->serialize =~ /^\s*#+\s*ABSTRACT:\s*(.+)$/m;
+
+  $self->log([ "couldn't find abstract in %s", $filename ]) unless $abstract;
+ 
+  my $name = $package;
+  $name .= " - $abstract" if $abstract;
 
   my $name_para = Pod::Elemental::Element::Nested->new({
     command  => 'head1',
     content  => 'NAME',
     children => [
-      Pod::Elemental::Element::Pod5::Ordinary->new({
-        content => "Module::Name - abstract text"
-      }),
+      Pod::Elemental::Element::Pod5::Ordinary->new({ content => $name }),
     ],
   });
   
@@ -54,7 +56,7 @@ Pod::Weaver::Section::Name - add a NAME section with abstract (for your Perl mod
 
 =head1 VERSION
 
-version 3.092970
+version 3.092971
 
 =head1 OVERVIEW
 
